@@ -16,6 +16,7 @@
 from oslo_serialization import jsonutils
 
 from mistralclient.api import base
+from mistralclient.api.v2 import executions
 
 
 class Task(base.Resource):
@@ -50,6 +51,16 @@ class TaskManager(base.ResourceManager):
 
         return self._get('/tasks/%s' % id)
 
+    def get_task_sub_executions(self, id, errors_only='', max_depth=-1):
+        task_sub_execs_path = '/tasks/%s/executions%s'
+        params = '?max_depth=%s&errors_only=%s' % (max_depth, errors_only)
+
+        return self._list(
+            task_sub_execs_path % (id, params),
+            response_key='executions',
+            returned_res_cls=executions.Execution
+        )
+
     def rerun(self, task_ex_id, reset=True, env=None):
         url = '/tasks/%s' % task_ex_id
 
